@@ -2,17 +2,17 @@
    Unix SMB/CIFS implementation.
    SMB client password change routine
    Copyright (C) Andrew Tridgell 1994-1998
-   
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
@@ -24,6 +24,7 @@
 #include "libsmb/libsmb.h"
 #include "libsmb/clirap.h"
 #include "libsmb/nmblib.h"
+#include "../libcli/smb/smbXcli_base.h"
 
 /*************************************************************
  Change a password on a remote machine using IPC calls.
@@ -33,10 +34,8 @@ NTSTATUS remote_password_change(const char *remote_machine, const char *user_nam
 				const char *old_passwd, const char *new_passwd,
 				char **err_str)
 {
-	struct nmb_name calling, called;
 	struct cli_state *cli = NULL;
 	struct rpc_pipe_client *pipe_hnd = NULL;
-	struct sockaddr_storage ss;
 	char *user, *domain, *p;
 
 	NTSTATUS result;
@@ -57,47 +56,19 @@ NTSTATUS remote_password_change(const char *remote_machine, const char *user_nam
 
 	*err_str = NULL;
 
-	if(!resolve_name( remote_machine, &ss, 0x20, false)) {
-		if (asprintf(err_str, "Unable to find an IP address for machine "
-			 "%s.\n", remote_machine) == -1) {
-			*err_str = NULL;
-		}
-		return NT_STATUS_UNSUCCESSFUL;
-	}
-
-	cli = cli_initialise();
-	if (!cli) {
-		return NT_STATUS_NO_MEMORY;
-	}
-
-	result = cli_connect(cli, remote_machine, &ss);
+	result = cli_connect_nb(remote_machine, NULL, 0, 0x20, NULL,
+				SMB_SIGNING_DEFAULT, 0, &cli);
 	if (!NT_STATUS_IS_OK(result)) {
 		if (asprintf(err_str, "Unable to connect to SMB server on "
 			 "machine %s. Error was : %s.\n",
 			 remote_machine, nt_errstr(result))==-1) {
 			*err_str = NULL;
 		}
-		cli_shutdown(cli);
 		return result;
 	}
 
-	make_nmb_name(&calling, global_myname() , 0x0);
-	make_nmb_name(&called , remote_machine, 0x20);
-
-	if (!cli_session_request(cli, &calling, &called)) {
-		if (asprintf(err_str, "machine %s rejected the session setup. "
-			 "Error was : %s.\n",
-			 remote_machine, cli_errstr(cli)) == -1) {
-			*err_str = NULL;
-		}
-		result = cli_nt_error(cli);
-		cli_shutdown(cli);
-		return result;
-	}
-
-	cli->protocol = PROTOCOL_NT1;
-
-	result = cli_negprot(cli);
+	result = smbXcli_negprot(cli->conn, cli->timeout, PROTOCOL_CORE,
+				 PROTOCOL_NT1);
 
 	if (!NT_STATUS_IS_OK(result)) {
 		if (asprintf(err_str, "machine %s rejected the negotiate "
@@ -105,7 +76,6 @@ NTSTATUS remote_password_change(const char *remote_machine, const char *user_nam
 			 remote_machine, nt_errstr(result)) == -1) {
 			*err_str = NULL;
 		}
-		result = cli_nt_error(cli);
 		cli_shutdown(cli);
 		return result;
 	}
@@ -126,7 +96,7 @@ NTSTATUS remote_password_change(const char *remote_machine, const char *user_nam
 		if (!NT_STATUS_EQUAL(result, NT_STATUS_PASSWORD_MUST_CHANGE) &&
 		    !NT_STATUS_EQUAL(result, NT_STATUS_PASSWORD_EXPIRED)) {
 			if (asprintf(err_str, "Could not connect to machine %s: "
-				 "%s\n", remote_machine, cli_errstr(cli)) == -1) {
+				 "%s\n", remote_machine, nt_errstr(result)) == -1) {
 				*err_str = NULL;
 			}
 			cli_shutdown(cli);
@@ -146,7 +116,7 @@ NTSTATUS remote_password_change(const char *remote_machine, const char *user_nam
 		if (!NT_STATUS_IS_OK(result)) {
 			if (asprintf(err_str, "machine %s rejected the session "
 				 "setup. Error was : %s.\n",        
-				 remote_machine, cli_errstr(cli)) == -1) {
+				 remote_machine, nt_errstr(result)) == -1) {
 				*err_str = NULL;
 			}
 			cli_shutdown(cli);
@@ -166,7 +136,7 @@ NTSTATUS remote_password_change(const char *remote_machine, const char *user_nam
 		}
 	}
 
-	result = cli_tcon_andx(cli, "IPC$", "IPC", "", 1);
+	result = cli_tree_connect(cli, "IPC$", "IPC", "", 1);
 	if (!NT_STATUS_IS_OK(result)) {
 		if (asprintf(err_str, "machine %s rejected the tconX on the "
 			     "IPC$ share. Error was : %s.\n",
@@ -180,13 +150,15 @@ NTSTATUS remote_password_change(const char *remote_machine, const char *user_nam
 	/* Try not to give the password away too easily */
 
 	if (!pass_must_change) {
-		result = cli_rpc_pipe_open_ntlmssp(cli,
-						   &ndr_table_samr.syntax_id,
-						   NCACN_NP,
-						   DCERPC_AUTH_LEVEL_PRIVACY,
-						   domain, user,
-						   old_passwd,
-						   &pipe_hnd);
+		result = cli_rpc_pipe_open_generic_auth(cli,
+							&ndr_table_samr,
+							NCACN_NP,
+							DCERPC_AUTH_TYPE_NTLMSSP,
+							DCERPC_AUTH_LEVEL_PRIVACY,
+							remote_machine,
+							domain, user,
+							old_passwd,
+							&pipe_hnd);
 	} else {
 		/*
 		 * If the user password must be changed the ntlmssp bind will
@@ -204,12 +176,12 @@ NTSTATUS remote_password_change(const char *remote_machine, const char *user_nam
 		if (lp_client_lanman_auth()) {
 			/* Use the old RAP method. */
 			if (!cli_oem_change_password(cli, user_name, new_passwd, old_passwd)) {
+				result = cli_nt_error(cli);
 				if (asprintf(err_str, "machine %s rejected the "
 					 "password change: Error was : %s.\n",
-					 remote_machine, cli_errstr(cli)) == -1) {
+					 remote_machine, nt_errstr(result)) == -1) {
 					*err_str = NULL;
 				}
-				result = cli_nt_error(cli);
 				cli_shutdown(cli);
 				return result;
 			}
@@ -220,7 +192,6 @@ NTSTATUS remote_password_change(const char *remote_machine, const char *user_nam
 				 remote_machine, nt_errstr(result)) == -1) {
 				*err_str = NULL;
 			}
-			result = cli_nt_error(cli);
 			cli_shutdown(cli);
 			return result;
 		}
@@ -295,12 +266,13 @@ NTSTATUS remote_password_change(const char *remote_machine, const char *user_nam
 				cli_shutdown(cli);
 				return NT_STATUS_OK;
 			}
+
+			result = cli_nt_error(cli);
 			if (asprintf(err_str, "machine %s rejected the password "
 				 "change: Error was : %s.\n",
-				 remote_machine, cli_errstr(cli)) == -1) {
+				 remote_machine, nt_errstr(result)) == -1) {
 				*err_str = NULL;
 			}
-			result = cli_nt_error(cli);
 			cli_shutdown(cli);
 			return result;
 		} else {
